@@ -7,7 +7,7 @@ use Moo;
 use MooX::Types::MooseLike::Base qw(ArrayRef Str);
 use namespace::autoclean;
 
-our $VERSION = '2.010';
+our $VERSION = '2.011';
 
 extends qw(
     Locale::TextDomain::OO::Extract::Base::RegexBasedExtractor
@@ -754,13 +754,13 @@ __END__
 Locale::TextDomain::OO::Extract::TT
 - Extracts internationalization data from TemplateToolkit code
 
-$Id: TT.pm 683 2017-08-22 18:41:42Z steffenw $
+$Id: TT.pm 693 2017-09-02 09:20:30Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/extract/trunk/lib/Locale/TextDomain/OO/Extract/TT.pm $
 
 =head1 VERSION
 
-2.010
+2.011
 
 =head1 DESCRIPTION
 
@@ -884,8 +884,9 @@ Quote and escape any text like: ' text {placeholder} \\ \' ' or q{ text {placeho
         $extractor->clear;
         $extractor->filename($_);            # dir/filename for reference
         $extractor->content_ref( \( path($_)->slurp_utf8 ) );
-        $exttactor->category('LC_Messages'); # set defaults or q{} is used
-        $extractor->domain('default');       # set defaults or q{} is used
+        $extractor->project('my project');   # set or default undef is used
+        $extractor->category('LC_MESSAGES'); # set or default q{} is used
+        $extractor->domain('my domain');     # set or default q{} is used
         $extractor->extract;
     }
     ... = $extractor->lexicon_ref;
